@@ -2,8 +2,9 @@
 # Licensed under the terms of the MIT License (see LICENSE.txt)
 
 from django.conf import settings
+from localeurl import LOCALE_INDEPENDENT_PATHS
 
-LOCALE_INDEPENDENT_PATHS = getattr(settings, 'LOCALE_INDEPENDENT_PATHS', ())
+SUPPORTED_LOCALES = dict(settings.LANGUAGES)
 
 def is_locale_independent(path):
     """
@@ -29,3 +30,14 @@ def strip_locale_prefix(path):
         if path.startswith(locale):
             return path[len(locale)-1:]
     return path
+
+def get_language(locale):
+    """
+    Returns the supported language (from settings.LANGUAGES)
+    """
+    if locale in SUPPORTED_LOCALES:
+        return locale
+    elif locale[:2] in SUPPORTED_LOCALES:
+        return locale[:2]
+    else:
+        return None
